@@ -3,6 +3,7 @@
 import abc
 import collections
 import enum
+import hashlib
 import random
 
 import attr
@@ -16,6 +17,7 @@ from cryptoparser.common.base import (
 from cryptoparser.common.classes import LanguageTag
 from cryptoparser.common.exception import InvalidValue, InvalidType, TooMuchData
 from cryptoparser.common.parse import ParsableBase, ParserBinary, ComposerBinary, ParserText, ComposerText
+from cryptoparser.common.utils import bytes_to_hex_string
 
 from cryptoparser.ssh.ciphersuite import (
     SshKexAlgorithm,
@@ -88,7 +90,7 @@ class SshProtocolMessage(ParsableBase):
             if '\r' in value or '\n' in value:
                 raise InvalidValue(value, SshProtocolMessage, 'comment')
             try:
-                value.encode('ascii')
+                six.ensure_binary(value, 'ascii')
             except UnicodeEncodeError as e:
                 six.raise_from(InvalidValue(value, SshProtocolMessage, 'comment'), e)
 
@@ -110,7 +112,7 @@ class SshProtocolMessage(ParsableBase):
         if software_version_and_comment[-1][-1] == '\r':
             software_version_and_comment[-1] = software_version_and_comment[-1][:-1]
 
-        software_version_parser = ParserText(software_version_and_comment[0].encode('ascii'))
+        software_version_parser = ParserText(six.ensure_binary(software_version_and_comment[0], 'ascii'))
         try:
             software_version_parser.parse_parsable('value', SshSoftwareVersionParsedVariant)
         except InvalidValue:
@@ -214,8 +216,8 @@ class SshLanguageVector(VectorString):
         return VectorParamSshLanguage()
 
 
-@attr.s  # pylint: disable=too-many-instance-attributes
-class SshKeyExchangeInit(SshMessageBase):
+@attr.s
+class SshKeyExchangeInit(SshMessageBase):  # pylint: disable=too-many-instance-attributes
     kex_algorithms = attr.ib(
         converter=SshKexAlgorithmVector,
         validator=attr.validators.instance_of(SshKexAlgorithmVector)
@@ -303,6 +305,39 @@ class SshKeyExchangeInit(SshMessageBase):
     def get_message_code(cls):
         return SshMessageCode.KEXINIT
 
+    @staticmethod
+    def _hassh(algorithm_vectors):
+        hassh_text = ';'.join([
+            ','.join([
+                algorithm if isinstance(algorithm, six.string_types) else algorithm.value.code
+                for algorithm in algorithms
+            ])
+            for algorithms in algorithm_vectors
+        ])
+
+        message = hashlib.md5()
+        message.update(six.ensure_binary(hassh_text, 'ascii'))
+
+        return bytes_to_hex_string(message.digest(), lowercase=True)
+
+    @property
+    def hassh(self):
+        return self._hassh([
+            self.kex_algorithms,
+            self.encryption_algorithms_client_to_server,
+            self.mac_algorithms_client_to_server,
+            self.compression_algorithms_client_to_server,
+        ])
+
+    @property
+    def hassh_server(self):
+        return self._hassh([
+            self.kex_algorithms,
+            self.encryption_algorithms_server_to_client,
+            self.mac_algorithms_server_to_client,
+            self.compression_algorithms_server_to_client,
+        ])
+
 
 class SshReasonCode(enum.IntEnum):
     HOST_NOT_ALLOWED_TO_CONNECT = 0x01
